## START: Set by rpmautospec
## (rpmautospec version 0.8.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 8;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           wavbreaker
Version:        0.16
Release:        %autorelease
Summary:        GUI tool to losslessly split WAV, MP2 and MP3 files into multiple parts

%global app_id net.sourceforge.wavbreaker

# The entire source is GPL-2.0-or-later, except for the AppData XML file, which
# is FSFAP.
License:        GPL-2.0-or-later AND FSFAP
URL:            https://wavbreaker.sourceforge.io
Source:         https://github.com/thp/wavbreaker/archive/%{version}/wavbreaker-%{version}.tar.gz

# Drop AppData ‘content_rating’ to fix #26
# https://github.com/thp/wavbreaker/pull/27
#
# Fixes:
#
# AppData XML file does not pass appstream CLI validation
# https://github.com/thp/wavbreaker/issues/26
Patch:          https://github.com/thp/wavbreaker/pull/27.patch

BuildRequires:  gcc
BuildRequires:  meson

BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
# Optional; provides MP2/MP3 support.
BuildRequires:  pkgconfig(libmpg123)
# Optional; provides Ogg Vorbis support.
BuildRequires:  pkgconfig(vorbisfile)

BuildRequires:  desktop-file-utils
BuildRequires:  gettext

# Still required by guidelines for now
# (https://pagure.io/packaging-committee/issue/1053):
BuildRequires:  libappstream-glib
# Matches what gnome-software and others use:
BuildRequires:  appstream

%description
This application’s purpose in life is to take a WAV file and break it up into
multiple WAV files. It makes a clean break at the correct position to burn the
files to an Audio CD without any dead air between the tracks.

wavbreaker also supports breaking up MP2 and MP3 files without re-encoding
meaning it’s fast and there is no generational loss. Decoding (using mpg123) is
only done for playback and waveform display.

The GUI displays a waveform summary of the entire file at the top. The middle
portion displays a zoomed-in view that allows you to select where to start
playing and where it will make the break. The bottom portion contains a list of
track breaks. You may change file names and uncheck parts that you do not want
to have written out to disk when saving.

There is also a command line tool wavmerge to merge WAV files together. If you
download a show and don’t like how it was tracked, you can merge them together
with wavmerge and then break them back up with wavbreaker. The wavmerge tool
will only work on files that have the same format (for example, 44.100 Hz
sample rate, 16-bit sample size, etc.).


%prep
%autosetup -p1 -n wavbreaker-%{version}
# Since we install any contrib scripts as documentation with the execute bit
# unset, we remove any shebangs rather than applying:
#   %%py3_shebang_fix contrib/
# Note also that this package neither BuildRequires nor Requires a Python
# interpreter.
find contrib/ -type f -name '*.py' -print -exec sed -r -i '1{/^#!/d}' '{}' '+'


%conf
%meson -Dmp3=true -Dogg_vorbis=true


%build
%meson_build


%install
%meson_install
%find_lang wavbreaker


%check
desktop-file-validate \
  %{buildroot}%{_datadir}/applications/%{app_id}.desktop

# Still required by guidelines for now
# (https://pagure.io/packaging-committee/issue/1053):
appstream-util validate-relax --nonet \
    %{buildroot}/%{_metainfodir}/%{app_id}.appdata.xml
# Matches what gnome-software and others use:
appstreamcli validate --no-net --explain \
    %{buildroot}/%{_metainfodir}/%{app_id}.appdata.xml


%files -f wavbreaker.lang
%license COPYING

%doc AUTHORS
%doc CHANGELOG.md
%doc CONTRIBUTORS
%doc README.md
%doc contrib/

%{_bindir}/wavbreaker
%{_bindir}/wavcli

%{_metainfodir}/%{app_id}.appdata.xml
%{_datadir}/applications/%{app_id}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{app_id}.svg

%{_mandir}/man1/wavbreaker.1*
%{_mandir}/man1/wavcli.1*


%changelog
## START: Generated by rpmautospec
* Sun May 11 2025 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16-8
- Update .rpmlintrc file for current rpmlint

* Sun Jan 19 2025 Fedora Release Engineering <releng@fedoraproject.org> - 0.16-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Sun Nov 03 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16-6
- Invoke %%cmake in %%conf rather than in %%build

* Sat Jul 20 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.16-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Sat Jan 27 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.16-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Jan 03 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16-2
- Improved patch for content rating in AppData XML

* Thu Dec 21 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.16-1
- Update to 0.16

* Thu Dec 21 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.15-1
- Update to 0.15

* Thu Dec 21 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.14-1
- Update to 0.14

* Thu Dec 21 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.13-1
- Update to 0.13

* Thu Dec 21 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.12-1
- Update to 0.12

* Sat Jul 22 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-30
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Sat Jan 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-29
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Sat Jul 23 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-28
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Sat Jan 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-27
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-26
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-25
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-24
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Fri Jan 31 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-23
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Sat Jul 27 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sun Feb 03 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.10-19
- Escape macros in %%changelog

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.10-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jun 20 2014 Yaakov Selkowitz <yselkowi@redhat.com> - 0.10-12
- Fix FTBFS with -Werror=format-security (#1037382, #1107132)

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Feb 11 2013 Parag Nemade <paragn AT fedoraproject DOT org> - 0.10-9
- Remove vendor tag from desktop file as per https://fedorahosted.org/fesco/ticket/1077
- Cleanup spec as per recently changed packaging guidelines

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Dec 06 2011 Adam Jackson <ajax@redhat.com> - 0.10-6
- Rebuild for new libpng

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Sep 23 2009 Orcan Ogetbil <oget[DOT]fedora[AT]gmail[DOT]com> - 0.10-4
- Update desktop file according to F-12 FedoraStudio feature

* Mon Jul 27 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jun 5 2008 Homer <dmaley at nc.rr.com> - 0.10-1
- move to latest upstream release

* Fri May 23 2008 Todd Zullinger <tmz@pobox.com> - 0.9-4
- fix license tag

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.9-3
- Autorebuild for GCC 4.3

* Tue Jan 22 2008 Homer <dmaley at nc.rr.com> 0.9-2
- bump release for F8 -> F9 upgrade path

* Tue Nov 20 2007 Homer <dmaley at nc.rr.com> 0.9-1
- move to latest upstream release

* Tue Aug 28 2007 Fedora Release Engineering <rel-eng at fedoraproject dot org> - 0.8.1-4
- Rebuild for selinux ppc32 issue.

* Tue Aug 28 2007 Homer <dmaley at nc.rr.com> 0.8.1-3
- bump rev for F-8 mass rebuild

* Fri Jul 6 2007 Homer <dmaley at nc.rr.com> 0.8.1-2
- new version 0.8.1

* Sun May 13 2007 Homer <dmaley at nc.rr.com> 0.8-1
- new version 0.8

* Tue Oct 3 2006 Homer <dmaley at nc.rr.com> 0.7-6
- added wavbreaker-tooltips.patch

* Thu Jun 1 2006 Homer <dmaley at nc.rr.com> 0.7-5
- replaced wavbreaker-0.7-browsedir-set_current_folder.patch w/
  wavbreaker-0.7-browsedir-set_current_folder-v2.patch

* Tue May 30 2006 Homer <dmaley at nc.rr.com> 0.7-4
- added wavbreaker-0.7-browsedir-set_current_folder.patch

* Mon Apr 3 2006 Homer <dmaley at nc.rr.com> 0.7-3
- fixed %%doc

* Tue Mar 21 2006 Homer <dmaley at nc.rr.com> 0.7-2
- added %%doc

* Mon Feb 27 2006 Homer <dmaley at nc.rr.com> 0.7-1
- initial 0.7 build

* Mon Feb 20 2006 Homer <dmaley at nc.rr.com> 0.7a-1
- initial 0.7a build

* Wed Jan 25 2006 Homer <dmaley at nc.rr.com> 0.6.1-6
- default to ALSA

* Mon Dec 19 2005 Homer <dmaley at nc.rr.com> 0.6.1-5
- more .spec cleanup

* Fri Dec 9 2005 Homer <dmaley at nc.rr.com> 0.6.1-4
- continued .spec cleanup

* Wed Dec 7 2005 Homer <dmaley at nc.rr.com> 0.6.1-3
- cleaned up .spec based on Fedora Extras guidelines

* Mon Sep 12 2005 Homer <homerj at nc.rr.com> 0.6-homer.2
- fixed progress bar for save-as (wavbreaker-saveas-progress.patch)

* Thu Jun 2 2005 Homer <homerj at nc.rr.com> 0.6-homer.1
- rebuilt for 0.6.1 (bugfix release)

* Wed Jun 1 2005 Homer <homerj at nc.rr.com> 0.6-homer.1
- 0.6 released

* Mon May 23 2005 Homer <homerj at nc.rr.com> 0.6c-homer.2
- 0.6c (beta) release

* Thu May 19 2005 Homer <homerj at nc.rr.com> 0.6b-homer.3
- SPEC file clean-up

* Sat Feb 12 2005 Homer <homerj at nc.rr.com> 0.6b-homer.2
- appconfig.c: added remember-driver patch

* Tue Feb 8 2005 Homer <homerj at nc.rr.com> 0.6b-homer.1
- 0.6b (beta) release
- Makefile.am: added -lasound to wavbreaker_LDADD to fix compile error

* Fri Oct 29 2004 Homer <homerj at nc.rr.com> 0.5-homer.2
- attempted fix file closing bug (wavbreaker-fclose.patch)
- added BuildRequires for gtk2-devel

* Tue Jul 13 2004 Homer <homerj at nc.rr.com> 0.5-homer.1
- rebuilt for 0.5 release

* Thu Jul 1 2004 Homer <homerj at nc.rr.com> 0.4-homer.4
- actually fixed icon bug

* Thu Jul 1 2004 Homer <homerj at nc.rr.com> 0.4-homer.2
- (failed) attempt to fix icon bug

* Tue Jun 15 2004 Homer <homerj at nc.rr.com>
- initial build

## END: Generated by rpmautospec
